/**
* This is the javascript code for an interactive Map Engine
* Created in April 2013 by Brian Hartley - www.bhartley.com
* Free to use and distribute, but link me maybe?
* Uses Google Maps API v3 for map and basic functions: https://developers.google.com/maps/documentation/javascript/reference
* Uses PHP and AJAX for database interaction and XML generation
* Tested with Chrome, Firefox, Safari (on iOS), and IE v10
**/



/** IE BUGS CURRENT 5/11/13
* Debugged with IE version 10
* Will not run properly in IE v8 or older
* [FIXED] CSS gradient background doesn't work (still broken in IE v8)
* [FIXED] request.onreadystatechange expects a function, throws 'type mismatch' error in IE (lines 106 and 246)
* [FIXED] bindInfoWindow on line 127 expects an object, throws 'object expected' error and breaks in IE
* [FIXED] 'invalid calling object' in compatibility script, line 34 - posts but does not refresh page
* [FIXED] Will post sucessfully and refresh, but will not display newly added markers without clearing cache
**/



// Generic do-nothing function, lines 85 and 163
function doNothing() {}



// Creating a global InfoWindow object
var infoWindow = new google.maps.InfoWindow({
	maxWidth: 350
});



// Creating an array containing four site icons
// Edit this with your own icons or use the ones included here
var siteIcons = [];

siteIcons['rig'] = new google.maps.MarkerImage(
	'images/rig_icon.png', 
	new google.maps.Size(25, 38), 
	null, 
	new google.maps.Point(12, 5)
);

siteIcons['report'] = new google.maps.MarkerImage(
	'images/marker_logo.png', 
	new google.maps.Size(15, 15), 
	null, 
	new google.maps.Point(7, 7)
);

siteIcons['report_new'] = new google.maps.MarkerImage(
	'images/marker_logo_new.png', 
	new google.maps.Size(15, 15), 
	null, 
	new google.maps.Point(7, 7)
);

siteIcons['well'] = new google.maps.MarkerImage(
	'images/well_icon_s.png', 
	new google.maps.Size(25, 20), 
	null, 
	new google.maps.Point(19, 5)
);



// HERE IS WHERE THE MAP FUNCTION BEGINS
window.onload = function() {

// Defining the map options
var options = {  
  zoom: 7,  // sets initial zoom level
  center: new google.maps.LatLng(47.539455,-100.471802),  // centers the map on this point on load
  mapTypeId: google.maps.MapTypeId.TERRAIN  
};

// Creating a map object and calling up the map constructor
// Refers to a div you create on your page called 'map'
// Position and size this div in your css
var map = new google.maps.Map(document.getElementById('map'), options); 
	
	
	
// Getting info from GET URL for display of db markers
window.downloadUrlGet = function(url, callback) {
  var request = window.ActiveXObject ?
	  new ActiveXObject('Microsoft.XMLHTTP') :
	  new XMLHttpRequest;

  request.onreadystatechange = function() {
	if (request.readyState == 4) {
	  request.onreadystatechange = window.doNothing;
	  callback(request, request.status);
	}
  };
  request.open('GET', url, true);
  request.send(null);
}



// Adding a click event listener to the db markers for infowindow activation
window.bindInfoWindow = function(marker, map, infoWindow, html) {
  google.maps.event.addListener(marker, 'click', function() {
	infoWindow.setContent(html);
	infoWindow.open(map, marker);
  });
}



// Downloading marker attributes from XML via GET URL
downloadUrlGet("includes/dbgenxml2.php", function(data) {
	var xml = data.responseXML;
	var markers = xml.getElementsByTagName("marker");
		for (var i = 0; i < markers.length; i++) {
			var point = new google.maps.LatLng(
				parseFloat(markers[i].getAttribute("lat")),
				parseFloat(markers[i].getAttribute("lon")));
			var title = markers[i].getAttribute("title");
			var description = markers[i].getAttribute("description");
			//var date = markers[i].getAttribute("date");


	var html = "<table id='markers_table'>" +
				"<tr><th>" + title + "</th></tr>" +
				"<tr><td>" + description + "</td></tr>" +
				//"<tr><td>" + date + "</td></tr>"
				"</table>"
	var marker = new google.maps.Marker({
	   map: map,
	   position: point,
	   icon: siteIcons['report'] // Change this to one of your own icons from the icon array
	});
	  window.bindInfoWindow(marker, map, infoWindow, html);
	}
});



// Defining the input fields for infowindowAdd and setting an 'id' for css styling
var addform = "<table id='infowindowAdd_table'>" +
			 "<tr><td>Title:</td> <td><input type='text' id='title' class='addForm_title' 'maxlength=50'/> </td> </tr>" +
			 "<tr><td>Description:</td> <td><textarea rows='3' cols='25' id='description' class='addForm_desc' maxlength='200'></textarea></td></tr>" +
			 "<tr><td><input id='cancel' type='button' value='Cancel' onclick='cancel()' /></td>" + 
			 "<td><input id='save' type='button' value='Save & Close' onclick='saveData()'/></td></tr></div>";
var infowindowAdd = new google.maps.InfoWindow({
 content: addform
});



// Adding a click event listener to activate the infoWindowAdd with the 'add marker' form
google.maps.event.addListenerOnce(map, "click", function(event) {
	addMarker = new google.maps.Marker({
	  position: event.latLng,
	  map: map,
	  draggable: true,
	  animation: google.maps.Animation.DROP,
	  icon: siteIcons['report_new']
	});
google.maps.event.addListener(addMarker, "click", function() {
	infowindowAdd.open(map, addMarker);
	});
});



// infowindowAdd 'Cancel' function: remove added marker and refresh map
window.cancel = function() {
	window.location.reload();
}
	
	
	
// infowindowAdd 'Save Data' Function
window.saveData = function() {
  var title = escape(document.getElementById("title").value);
  var description = escape(document.getElementById("description").value);
  
	// Defines a rectangle with the approxinate (sw), (ne) coordinates of North Dakota
	// I used this to limit posting to within the approximate ND borders, delete or comment out if not needed
	// Or, specify bounding coordinates of (-85.0, -180.0), (85.0, 180.0) for entire world to avoid screwing with the if/else block that starts on line 197
  var Bounds = new google.maps.LatLngBounds(new google.maps.LatLng(45.943511,-104.053345), new google.maps.LatLng(49.0, -96.5));
  var latlng = addMarker.getPosition();
  var inBounds = Bounds.contains(latlng);
  
  var url = "includes/addrow.php?title=" + title + 
			"&description=" + description + "&lat=" + latlng.lat() + "&lon=" + latlng.lng();
			
	  // Test to see if marker is within North Dakota and reject or post
	  // Test that 'title' and 'description' are filled in with valid chars, and have valid lengths
	  // the 'message' element is a div placed near your 'map' div, used to display error and post messages
	if (inBounds == false) {
		document.getElementById("message").innerHTML = "This marker is outside of North Dakota.";
		return;
		} else if (unescape(description).length > 200) {
			document.getElementById("message").innerHTML = "Please limit your description to 200 characters or less."; // limits description to 200 chars
			return;
		} else if (unescape(title).length > 50) {
			document.getElementById("message").innerHTML = "Please limit your title to 50 characters or less."; // limits title to 50 chars
			return;
		} else if ((unescape(title).length < 3) || (unescape(description).length < 10)) {
			document.getElementById("message").innerHTML = "Please enter a valid title and description."; // ensures adequte length of inputs
			return;
		} else if ((!unescape(title).replace(/\s/g, "").length) || (!unescape(description).replace(/\s/g, "").length)) {
			document.getElementById("message").innerHTML = "Please enter legitimate characters."; // will not allow posts containing only spaces or tabs
			return;
		} else if (inBounds == true) {
			downloadUrlPost(url, function(data, responseCode) {
				if (responseCode == 200 && data.length <= 1) {
					infowindowAdd.close();
					document.getElementById("message").innerHTML = "Report submitted. Thank you for your contribution.";
					//setTimeout(window.location.reload.bind(window.location), 2000);
					setTimeout(function() {window.location.reload(window.location);}, 2000); // fixed the setTimeout for IE
					} else {
						document.getElementById("message").innerHTML = "Post failed. Click 'cancel' and try again.";
					}
		})
	} else {
		document.getElementById("message").innerHTML = "Something bad happened. Email the webmaster and try again later.";
		}
	};
  
  
  
  // Sending info from POST URL - post-add event
window.downloadUrlPost = function(url, callback) {
  var request = window.ActiveXObject ?
	  new ActiveXObject('Microsoft.XMLHTTP') :
	  new XMLHttpRequest;

  request.onreadystatechange = function() {
	if (request.readyState == 4) {
	  request.onreadystatechange = window.doNothing;
	  callback(request.responseText, request.status);
	}
  };
  request.open('GET', url, true);
  request.send(null);
}



} // MAP FUNCTION ENDS